@@ -11,9 +11,6 @@ from almost_empty.helper import (
 
 
 class TestHelper(unittest.TestCase):
-    def setUp(self):
-        pass
-
     def test_random_string(self):
         length = 10
 
@@ -63,8 +60,6 @@ class TestHelper(unittest.TestCase):
 
         self.assertTrue(os.path.isfile(os.path.join(temp_dir, '.gitignore')))
 
-    def tearDown(self):
-        pass
 
 if __name__ == '__main':
     unittest.main()
